@@ -4,7 +4,7 @@ use std::convert::TryFrom;
 use std::error::Error;
 use std::fmt::{Debug, Display, Formatter};
 
-/// Skills 是代表了一个玩家在作业时可以使用的一个技能的枚举。
+/// 代表一个玩家在作业时可以使用的一个技能的枚举。
 #[cfg_attr(feature = "serde-support", derive(Serialize, Deserialize))]
 #[derive(Copy, Clone, Debug)]
 #[repr(u8)]
@@ -262,7 +262,7 @@ impl Display for UnknownSkillErr {
 
 impl Error for UnknownSkillErr {}
 
-/// Condition 代表了当前的“制作状态”，也就是俗称的球色。
+/// 代表了当前的“制作状态”，也就是俗称的球色。
 #[derive(Copy, Clone, Debug)]
 pub enum Condition {
     // 白：通常
@@ -339,15 +339,20 @@ impl Condition {
     }
 }
 
+/// 玩家装备属性
 #[derive(Copy, Clone)]
 pub struct Attributes {
+    /// 玩家等级
     pub level: i32,
+    /// 制作精度
     pub craftsmanship: i32,
+    /// 加工精度
     pub control: i32,
+    /// 制作力
     pub craft_points: i32,
 }
 
-/// Recipe 储存了一次制作中配方的信息。
+/// 储存了一次制作中配方的信息。
 #[derive(Copy, Clone)]
 pub struct Recipe {
     /// 配方品级
@@ -929,7 +934,7 @@ impl Recipe {
             520 => Some((2620, 2540)),
             _ => None,
         }
-            .unwrap();
+        .unwrap();
 
         Recipe {
             rlv,
@@ -947,16 +952,29 @@ impl Recipe {
 /// Buffs 储存了一次制作中玩家全部buff状态信息
 #[derive(Copy, Clone, Default)]
 pub struct Buffs {
+    /// 元素之美名
     pub name_of_the_elements: Option<DurationBuff>,
+    /// 坚信
     pub muscle_memory: Option<DurationBuff>,
+    /// 阔步
     pub great_strides: Option<DurationBuff>,
+    /// 崇敬
     pub veneration: Option<DurationBuff>,
+    /// 改革
     pub innovation: Option<DurationBuff>,
+    /// 内静
     pub inner_quiet: Option<LayerBuff>,
+    /// 最终确认
     pub final_appraisal: Option<DurationBuff>,
+    /// 掌握
     pub manipulation: Option<DurationBuff>,
+    /// 俭约 OR 长期俭约
     pub wast_not: Option<DurationBuff>,
+    /// 中级加工预备
+    /// 假想buff，用于处理 加工-中级加工 的连击。
     pub standard_touch_prepared: Option<DurationBuff>,
+    /// 观察（注视预备）
+    /// 假想buff，用于处理 观察-注释制作 OR 观察-注视加工 的连击。
     pub observed: Option<DurationBuff>,
 }
 
@@ -1125,7 +1143,7 @@ impl Status {
         c
     }
 
-    fn consume_durability(&mut self, durability: i32) {
+    fn calc_durability(&self, durability: i32) -> i32 {
         let mut reduce = durability;
         if let Condition::Sturdy = self.condition {
             reduce -= reduce / 2;
@@ -1133,7 +1151,11 @@ impl Status {
         if self.buffs.wast_not.is_some() {
             reduce -= reduce / 2;
         }
-        self.durability -= reduce;
+        reduce
+    }
+
+    fn consume_durability(&mut self, durability: i32) {
+        self.durability -= self.calc_durability(durability);
     }
 
     fn consume_craft_point(&mut self, cp: i32) {
@@ -1214,7 +1236,8 @@ impl Status {
             Skills::CarefulSynthesis => self.cast_synthesis(7, 10, 1.5),
             Skills::FocusedSynthesis => self.cast_synthesis(5, 10, 2.0),
             Skills::Groundwork => {
-                let e = if self.durability < 20 { 1.5 } else { 3.0 };
+                let d = self.calc_durability(20);
+                let e = if self.durability < d { 1.5 } else { 3.0 };
                 self.cast_synthesis(18, 20, e)
             }
             Skills::IntensiveSynthesis => self.cast_synthesis(6, 10, 4.0),
@@ -1373,18 +1396,18 @@ impl Status {
         };
         addon
             + match action {
-            Skills::HastyTouch => 0.6,
-            Skills::RapidSynthesis => 0.5,
-            Skills::PatientTouch => 0.5,
-            Skills::FocusedSynthesis | Skills::FocusedTouch => {
-                if self.buffs.observed.is_some() {
-                    1.0
-                } else {
-                    0.5
+                Skills::HastyTouch => 0.6,
+                Skills::RapidSynthesis => 0.5,
+                Skills::PatientTouch => 0.5,
+                Skills::FocusedSynthesis | Skills::FocusedTouch => {
+                    if self.buffs.observed.is_some() {
+                        1.0
+                    } else {
+                        0.5
+                    }
                 }
+                _ => return 1.0,
             }
-            _ => return 1.0,
-        }
     }
 
     /// 当前状态是否允许发动某技能。
@@ -1407,10 +1430,10 @@ impl Status {
         match action {
             _ if action.unlock_level() > self.attributes.level => Err(PlayerLevelTooLow),
             Skills::TricksOfTheTrade | Skills::IntensiveSynthesis | Skills::PreciseTouch
-            if !matches!(self.condition, Condition::Good | Condition::Excellent) =>
-                {
-                    Err(RequireGoodOrExcellent)
-                }
+                if !matches!(self.condition, Condition::Good | Condition::Excellent) =>
+            {
+                Err(RequireGoodOrExcellent)
+            }
             Skills::PrudentTouch if self.buffs.wast_not.is_some() => Err(NotAllowedInWastNotBuff),
             Skills::MuscleMemory | Skills::Reflect | Skills::TrainedEye if self.step != 0 => {
                 Err(OnlyAllowedInFirstStep)
@@ -1708,7 +1731,7 @@ mod tests {
             (Skills::StandardTouch, 30, 83, 3671, 2425),
             (Skills::ByregotsBlessing, 20, 59, 3671, 4188),
         ]
-            .iter()
+        .iter()
         {
             s.cast_action(step.0);
             assert_eq!(s.durability, step.1);
@@ -1744,7 +1767,7 @@ mod tests {
             (Skills::ByregotsBlessing, 20, 201, 1017, 3312),
             (Skills::StandardTouch, 10, 169, 1017, 4015),
         ]
-            .iter()
+        .iter()
         {
             s.cast_action(step.0);
             assert_eq!(s.durability, step.1);
@@ -1762,7 +1785,7 @@ mod tests {
             (Skills::MuscleMemory, 50, 351, 1017, 0),
             (Skills::Groundwork, 30, 333, 3051, 0),
         ]
-            .iter()
+        .iter()
         {
             s.cast_action(step.0);
             assert_eq!(s.durability, step.1);
@@ -1782,7 +1805,7 @@ mod tests {
             (Skills::MastersMend, 60, 157, 0, 375),
             (Skills::MastersMend, 60, 69, 0, 375),
         ]
-            .iter()
+        .iter()
         {
             s.cast_action(step.0);
             assert_eq!(s.durability, step.1);
@@ -1808,7 +1831,7 @@ mod tests {
             (Skills::PreparatoryTouch, 10, 76, 2034, 4326),
             (Skills::DelicateSynthesis, 0, 44, 2373, 5496),
         ]
-            .iter()
+        .iter()
         {
             s.cast_action(step.0);
             assert_eq!(s.durability, step.1);
@@ -1838,7 +1861,7 @@ mod tests {
             Skills::Groundwork,
             Skills::CarefulSynthesis,
         ]
-            .iter()
+        .iter()
         {
             s.cast_action(step);
         }
@@ -1863,7 +1886,7 @@ mod tests {
             Skills::PrudentTouch,
             Skills::BasicTouch,
         ]
-            .iter()
+        .iter()
         {
             s.cast_action(step);
         }
@@ -1900,7 +1923,7 @@ mod tests {
             (Skills::RapidSynthesis, true, 9006, 634, Condition::Normal),
             (Skills::RapidSynthesis, true, 11376, 634, Condition::Normal),
         ]
-            .iter()
+        .iter()
         {
             if step.1 {
                 s.cast_action(step.0);
@@ -1972,8 +1995,8 @@ mod tests {
             (Skills::PreparatoryTouch, true, 12460, Condition::Good),
             (Skills::PreciseTouch, true, 19840, Condition::Centered),
         ]
-            .iter()
-            .enumerate()
+        .iter()
+        .enumerate()
         {
             if *success {
                 s.cast_action(*skill);
